
[![Built Status](https://api.cirrus-ci.com/github/imubit/data-agent-aspen-ip21.svg?branch=main)](https://cirrus-ci.com/github/imubit/data-agent-aspen-ip21)
[![PyPI-Server](https://img.shields.io/pypi/v/data-agent-aspen-ip21.svg)](https://pypi.org/project/data-agent-aspen-ip21/)
[![Project generated with PyScaffold](https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold)](https://pyscaffold.org/)

# data-agent-aspen-ip21

> Data Agent plugin for AspenTech InfoPlus.21

The plugin allows Data Extractor do access data on IP21 systems using ODBC connection.
